<?php

namespace App\Http\Controllers;

use App\Helpers\Detector;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;


class UserController extends Controller
{
    public function __construct()
    {
//        $this->middleware([ "auth" ])->only("logout");
//        $this->middleware([ "guest" ])->only("login");
//
//        $this->middleware([ "permission:user.list", "role:admin" ])->only("index");
//        $this->middleware([ "permission:user.show", "role:admin" ])->only("show");
//        $this->middleware([ "permission:user.edit", "role:admin" ])->only([ "edit", "update" ]);
//        $this->middleware([ "permission:user.delete", "role:admin" ])->only("delete");
    }

    /**
     * Display a listing of the resource.
     *
     * @param Request $request
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index(Request $request)
    {
        $users = User::query()->paginate($request->query("page", 20));

        return Response::detect("users.index", [ "users" => $users ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function create()
    {
        return Response::detect("users.create");
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function store(Request $request)
    {
        Log::debug("STORE FUNCTION");

        $data = $request->validate([
            "name_first" => "required|max:255",
            "name_last" => "required|max:255",
            "email" => "required|email|unique:users",
            "password" => "required|max:60",
            "phone" => "required|unique:users",

        ]);

        Log::debug("FINISHED VALIDATION?");

        $user = new User($data);

        Log::debug("CREATED USER [NOT PERSISTED YET]");

        $user->save();

        Log::debug("SAVED USER");

        return Response::detect("users.store");
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function show($id)
    {
        $user = User::find($id);

        return Response::detect("users.show", [
            "user" => $user
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function edit($id)
    {
        $user = User::find($id);

        return Response::detect("users.edit", [
            "user" => $user
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function update(Request $request, $id)
    {
        $data = $request->all();

//        $data = $request->validate([
//            "name_first" => "max:255",
//            "name_last" => "max:255",
//            "email" => "email|unique:users",
//            "password" => "max:60",
//            "phone" => "unique:users",
//        ]);

        // Validates if the user is updating itself or another user.
//        if($id === Auth::id()) {
//            $user = Auth::user();
//
//            $user->update($data);
//
//            $user->save();
//            return Response::detect("users.edit", [
//                "user" => $user
//            ]);
//        }

        //TODO: Implement when security's ready!!!
//        else if(Auth::user()->hasPermissionTo("user.edit")) {
            $user = User::find($id);

            /** @var User $user */
            $user->update($data);

            $user->save();
//        }

        $users = User::query()->paginate(20);

        return Response::detect("users.index", [
            "users" => $users
        ]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function destroy($id)
    {
//        if($id === Auth::id()) {
//            $user = Auth::user();
//            $user->delete();
//        }
//        else if(Auth::user()->hasPermissionTo("user.delete")) {
            $user = User::find($id);

            $user->delete();
//        }

        return redirect()->route("users.index");
    }

    /*******************************************/
    /*              Authentication             */
    /*******************************************/

    public function showLogin() {
        return view("admin.users.login");
    }

    public function login(Request $request) {
        $data = $request->only("email", "password");

        if(Auth::attempt($data)) {
            //TODO: Implement home?
            return redirect()->route("users.index");
        }

        return redirect()->back(303);
    }

    public function logout(Request $request) {
        Auth::logout();

        return redirect()->to("/");
    }
}
